#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

install_requires = \
['click', 'daiquiri', 'speedtest-cli']

entry_points = \
{'console_scripts': ['speedtest-logger = speedtest_logger:main']}

setup(name='speedtest_logger',
      version='0.0.6',
      description='A package to log broadband speed test results',
      author='Owen Campbell',
      author_email='owen.campbell@tanti.org.uk',
      url='http://owencampbell.me.uk',
      py_modules=['speedtest_logger'],
      install_requires=install_requires,
      entry_points=entry_points,
     )
